@@ -7,6 +7,7 @@ from pandas.io.parsers import TextParser
 from pandas.errors import EmptyDataError
 from typing import Mapping, Any
 from .util import DEFAULT_TIMEOUT, DEFAULT_CHECK_INTERVAL, DEFAULT_FAIL_WHEN_LOCKED, LOCK_METHOD
+from copy import deepcopy
 
 
 class NotFunctionError(Exception):
@@ -280,9 +281,9 @@ class FileHandler(object):
             except EmptyDataError:
                 df = DataFrame()
 
-            return df
+            return deepcopy(df)
         else:
-            return DataFrame()
+            return deepcopy(DataFrame())
 
 
 class FileParser(object):
