@@ -1,3 +1,6 @@
+import contextlib
+import tempfile
+
 from ..filehandler import FileHandler
 from ..util import maybe_convert_usecols, get_version, Scalar
 from distutils.version import LooseVersion
@@ -39,55 +42,47 @@ class OpenPYXLReader(FileHandler):
             self.sheet_names = sheet_names
 
         if self.file_path:
-            from openpyxl import load_workbook
-
-            xls_file = load_workbook(self.file_path)
-
             try:
-                for tab in xls_file.sheetnames:
-                    if not self.sheet_names or tab.lower() in self.sheet_names:
-                        xls_ws = xls_file[tab]
-                        sheets[tab] = xls_ws.max_row
-
-            finally:
-                xls_file.close()
+                with load_workbook(self.file_path) as xls_file:
+                    for tab in xls_file.sheetnames:
+                        if not self.sheet_names or tab.lower() in self.sheet_names:
+                            xls_ws = xls_file[tab]
+                            sheets[tab] = xls_ws.max_row
+            except:
+                pass
 
         return sheets
 
     def __parse(self, handler=None, buffer=None, **kwargs):
-        from openpyxl import load_workbook
-
-        xls_file = load_workbook(self.file_path)
         sheets = dict()
 
         try:
-            if self.flag_read_only and xls_file.read_only:
-                raise ReadOnlyError
+            with load_workbook(self.file_path) as xls_file:
+                if self.flag_read_only and xls_file.read_only:
+                    raise ReadOnlyError
 
-            for tab in xls_file.sheetnames:
-                if not self.sheet_names or tab.lower() in self.sheet_names:
-                    xls_ws = xls_file[tab]
+                for tab in xls_file.sheetnames:
+                    if not self.sheet_names or tab.lower() in self.sheet_names:
+                        xls_ws = xls_file[tab]
 
-                    if handler:
-                        self.__openpyxl_sheet(sheet=xls_ws, handler=handler, buffer=buffer, **kwargs)
-                    else:
-                        sheets[tab] = self.__openpyxl_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
+                        if handler:
+                            self.__openpyxl_sheet(sheet=xls_ws, handler=handler, buffer=buffer, **kwargs)
+                        else:
+                            sheets[tab] = self.__openpyxl_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
 
-                    if self.truncate:
-                        try:
-                            if xls_ws.max_row > 1:
-                                xls_ws.delete_rows(2, xls_ws.max_row - 1)
+                        if self.truncate:
+                            try:
+                                if xls_ws.max_row > 1:
+                                    xls_ws.delete_rows(2, xls_ws.max_row - 1)
 
-                            xls_file.save(filename=file)
-                        except Exception as e:
-                            log.error(format_exc)
-                            log.error('Excel Sheet truncate Failed - Ecode {0}, {1}'.format(type(e).__name__, str(e)))
-                            pass
-        finally:
-            if hasattr(xls_file, '_archive') and hasattr(xls_file._archive, 'close'):
-                xls_file._archive.close()
-
-            xls_file.close()
+                                xls_file.save(filename=file)
+                            except Exception as e:
+                                log.error(format_exc)
+                                log.error('Excel Sheet truncate Failed - Ecode {0}, {1}'.format(type(e).__name__,
+                                                                                                str(e)))
+                                pass
+        except:
+            pass
 
         if sheets:
             return sheets
@@ -582,3 +577,19 @@ class PYXLSBReader(FileHandler):
                 return float(cell.v)
 
         return cell.v
+
+
+@contextlib.contextmanager
+def load_workbook(file_path, *args, **kwargs):
+    from openpyxl import load_workbook
+    from os.path import join
+    from os import remove
+
+    wb = load_workbook(file_path, *args, **kwargs)
+    yield wb
+
+    path = join(tempfile.gettempdir(), basename(file_path))
+    wb.save(path)
+    wb.close()
+    remove(path)
+    del wb
