@@ -13,12 +13,12 @@ class XMLReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer in self.streams:
-                self.__parse(handler=handler, buffer=buffer)
+            for handler, buffer, kwargs in self.streams:
+                self.__parse(handler=handler, buffer=buffer, **kwargs)
         else:
             return self.__parse()
 
-    def __parse(self, handler=None, buffer=None):
+    def __parse(self, handler=None, buffer=None, **kwargs):
         from ..filehandler import is_an_xml
 
         if is_an_xml(self.file_path):
@@ -31,11 +31,13 @@ class XMLReader(FileHandler):
                     self.dict_var = self.__parse_element(item, self.dict_var)
 
                 return self.dict_var
+            elif handler:
+                self.__parse_xml_root(xml_objs, handler, buffer, **kwargs)
             else:
-                self.__parse_xml_root(xml_objs, handler, buffer)
+                return self.__parse_xml_root(xml_objs, handler, buffer, **kwargs)
 
     @staticmethod
-    def __parse_xml_root(xml_objs, handler=None, buffer=None):
+    def __parse_xml_root(xml_objs, handler=None, buffer=None, **kwargs):
         xml_dicts = list()
         row_num = 0
         header = None
@@ -47,7 +49,7 @@ class XMLReader(FileHandler):
                 header = converted_row
 
             if handler and buffer <= len(xml_dicts):
-                handler(self.file_path, self.__parse_df(xml_dicts), row_num - len(xml_dicts) + 1)
+                handler(self.file_path, self.__parse_df(xml_dicts), row_num - len(xml_dicts) + 1, **kwargs)
                 xml_dicts.clear()
                 xml_dicts.append(header)
 
@@ -55,7 +57,7 @@ class XMLReader(FileHandler):
 
         if handler:
             row_num -= 1
-            handler(self.file_path, self.__parse_df(xml_dicts), row_num - len(xml_dicts) + 1)
+            handler(self.file_path, self.__parse_df(xml_dicts), row_num - len(xml_dicts) + 1, **kwargs)
         else:
             return self.__parse_df(xml_dicts)
 
